## Version 0.0.13

This new version includes an update to the example about querying PDFs and a bug fix related to query nodes. The version has been bumped from 0.0.12 to 0.0.13.

### New Features

- The example about querying PDFs has been updated to provide more clarity and better understanding (8169ce) (Eric Ma)

### Bug Fixes

- Fixed a bug where query nodes were hard-coded to 3, which limited the flexibility of the system. Now, the number of query nodes is dynamic (6802ac) (Eric Ma)

### Deprecations

- No deprecations in this release.
